@@ -1,5 +1,6 @@
 __all__ = ['commands', 'datastore', 'formatting', 'launch', 'parameters',
            'programs', 'projects', 'records', 'recordstore', 'versioncontrol',
-           'dependency_finder', 'external', 'web', 'decorators']
+           'dependency_finder', 'external', 'web', 'decorators', 'publishing',
+           'users', 'core']
 
-__version__ = "0.4.0"    
+__version__ = "0.5.0"    
