@@ -12,6 +12,8 @@ FileSystemDataStore - provides methods for accessing files stored on a local fil
                       system, under a given root directory.
 ArchivingFileSystemDataStore - provides methods for accessing files written to
                       a local file system then archived as .tar.gz.
+MirroredFileSystemDataStore - provides methods for accessing files written to
+                      a local file system then mirrored to a web server
 
 Functions
 ---------
@@ -23,8 +25,9 @@ get_data_store() - return a DataStore object based on a class name and
 from base import DataKey, IGNORE_DIGEST
 from filesystem import FileSystemDataStore
 from archivingfs import ArchivingFileSystemDataStore
+from mirroredfs import MirroredFileSystemDataStore
+
 
-    
 def get_data_store(type, parameters):
     cls = eval(type)
     return cls(**parameters)
