@@ -26,10 +26,17 @@ string_table      - Convert a table written as a multi-line string into a dict o
 
 """
 
-import urllib, copy, warnings, math
+import urllib, copy, warnings, math, urllib2
 from urlparse import urlparse
+from os import environ, path
 from sumatra.external.NeuroTools.random import ParameterDist, GammaDist, UniformDist, NormalDist
 
+if 'HTTP_PROXY' in environ:
+    HTTP_PROXY = environ['HTTP_PROXY'] # user has to define it
+    ''' next lines are for communication to urllib of proxy information '''
+    proxy_support = urllib2.ProxyHandler({"https":HTTP_PROXY})
+    opener = urllib2.build_opener(proxy_support, urllib2.HTTPHandler)
+    urllib2.install_opener(opener)
 
 def isiterable(x):
     return (hasattr(x,'__iter__') and not isinstance(x, basestring))
@@ -193,9 +200,18 @@ class ParameterSet(dict):
                                 false=False,  # files
                                 ))            
         try:
-            D = eval(s, global_dict)
+            if 'file://' in s:
+                path = s.split('file://')[1]
+                ifile = open(path, 'r')
+                content = ifile.read()
+                ifile.close()
+                D = eval(content, global_dict)           
+            else:
+                D = eval(s, global_dict)
         except SyntaxError, e:
             raise SyntaxError("Invalid string for ParameterSet definition: %s\n%s" % (s,e))
+        except TypeError, e:
+            raise SyntaxError("Invalid string for ParameterSet definition: %s" % e)
         return D or {}
     
     @staticmethod
@@ -220,19 +236,23 @@ class ParameterSet(dict):
         
         self._url = None
         if isinstance(initialiser, basestring): # url or str
-            try:
-                # can't handle cases where authentication is required
-                # should be rewritten using urllib2 
-                #scheme, netloc, path, \
-                #        parameters, query, fragment = urlparse(initialiser)
-                f = urllib.urlopen(initialiser)
+            if path.exists(initialiser):
+                f = open(initialiser)
                 pstr = f.read()
                 self._url = initialiser
-            except IOError, e:
-                pstr = initialiser
-                self._url = None
-            else:
                 f.close()
+            else:
+                try:
+                    # can't handle cases where authentication is required
+                    # should be rewritten using urllib2 
+                    f= urllib2.urlopen(initialiser)
+                    pstr = f.read()
+                    self._url = initialiser
+                except IOError, e:
+                    pstr = initialiser
+                    self._url = None
+                else:
+                    f.close()
 
             initialiser = ParameterSet.read_from_str(pstr)
         
@@ -354,7 +374,7 @@ class ParameterSet(dict):
     def pretty(self, indent='  ', expand_urls=False):
         """
         Return a unicode string representing the structure of the `ParameterSet`.
-        `eval`uating the string should recreate the object.
+        `eval`\uating the string should recreate the object.
         """
         def walk(d, indent, ind_incr):
             s = []
