@@ -4,22 +4,26 @@ The parameters module handles different parameter file formats.
 The original idea was that all parameter files will be converted to a single
 internal parameter format, the NeuroTools ParameterSet class. This will allow
 fancy searching/comparisons based on parameters. However, we don't do this at
-the moment, the only methods that are used are `update()` and `save()
+the moment, the only methods that are used are `update()` and `save()`
 
 Classes
 -------
 
-NTParameterSet           - handles parameter files in the NeuroTools parameter
-                           set format, based on nested dictionaries
-SimpleParameterSet       - handles parameter files in a simple "name = value"
-                           format, with no nesting or grouping.
-ConfigParserParameterSet - handles parameter files in traditional config file
-                           format, as parsed by the standard Python ConfigParser
-                           module.
+NTParameterSet:
+    handles parameter files in the NeuroTools parameter set format, based on
+    nested dictionaries.
+SimpleParameterSet:
+    handles parameter files in a simple "name = value" format, with no nesting
+    or grouping.
+ConfigParserParameterSet
+    handles parameter files in traditional config file format, as parsed by the
+    standard Python :mod:`ConfigParser` module.
+JSONParameterSet
+    handles parameter files in JSON format
+YAMLParameterSet
+    handles parameter files in YAML format
+
 """
-# JSONParameterSet and YAMLParameterSet should be useful and straightforward to
-# implement. XMLParameterSet could also be useful, but is unlikely to be
-# straightforward.
 
 from __future__ import with_statement
 import os.path
@@ -32,6 +36,82 @@ try:
 except ImportError:
     import simplejson as json
 
+try:
+    import yaml
+    yaml_loaded = True
+except ImportError:
+    yaml_loaded = False
+
+
+class YAMLParameterSet(object):
+    """
+    Handles parameter files in YAML format, as parsed by the
+    PyYAML module
+    """
+
+    def __init__(self, initialiser):
+        """
+        Create a new parameter set from a file or string.
+        """
+        if yaml_loaded:
+            try:
+                if os.path.exists(initialiser):
+                    with open(initialiser) as fid:
+                        self.values = yaml.load(fid)
+                else:
+                    if initialiser:
+                        self.values = yaml.load(initialiser)
+                    else:
+                        self.values = {}
+            except yaml.YAMLError:
+                raise SyntaxError("Misformatted YAML file")
+            if not isinstance(self.values, dict):
+                raise SyntaxError("YAML file cannot be represented as a dict")
+        else:
+            raise ImportError("Cannot import PyYAML module")
+
+    def __str__(self):
+        return self.pretty()
+
+    def __getitem__(self, name):
+        return self.values[name]
+
+    def __eq__(self, other):
+        return self.as_dict() == other.as_dict()
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def pretty(self, expand_urls=False):
+        """
+        Return a string representation of the parameter set, suitable for
+        creating a new, identical parameter set.
+
+        expand_urls is present for compatibility with NTParameterSet, and is
+                    not used.
+        """
+
+        output = yaml.dump(self.values, indent=4)
+        return output
+
+    def as_dict(self):
+        return self.values
+
+    def save(self, filename):
+        with open(filename, "w") as f:
+            yaml.dump(self.values, f)
+
+    def update(self, E, **F):
+        __doc__ = dict.update.__doc__
+        self.values.update(E, **F)
+
+    def pop(self, key, d=None):
+        if key in self.values:
+            return self.values.pop(key)
+        else:
+            return d
+
+
 class NTParameterSet(NeuroTools.parameters.ParameterSet):
     # just a re-name, to clarify things
     pass
@@ -319,6 +399,13 @@ class JSONParameterSet(object):
 
 def build_parameters(filename):
 
+    if yaml_loaded:
+        try:
+            parameters = YAMLParameterSet(filename)
+            return parameters
+        except SyntaxError:
+            pass
+
     try:
         parameters = JSONParameterSet(filename)
         return parameters
