@@ -5,27 +5,36 @@ files, to support the ability to customize Sumatra's behaviour for specific tool
 Classes
 -------
 
-Executable       - represents a generic executable, about which nothing is known
-                   except its name. The base class for specific simulator/
-                   analysis tool classes.
-NESTSimulator    - represents the NEST neuroscience simulator.
-NEURONSimulator  - represents the NEURON neuroscience simulator.
-PythonExecutable - represents the Python interpreter executable.
+Executable
+    represents a generic executable, about which nothing is known except its
+    name. The base class for specific simulator/analysis tool classes.
+PythonExecutable
+    represents the Python interpreter executable.
+MatlabExecutable
+    represents the Matlab interpreter executable.
+NESTSimulator
+    represents the NEST neuroscience simulator.
+NEURONSimulator
+    represents the NEURON neuroscience simulator.
+GENESISSimulator
+    represents the GENESIS neuroscience simulator.
 
 Functions
 ---------
 
-get_executable()      - Return an appropriate subclass of Executable, given
-                        either the path to an executable file or a script file
-                        that can be run with a given tool.
-register_executable() - Register new subclasses of Executable that can be
-                        returned by get_executable().
+get_executable()
+    Return an appropriate subclass of Executable, given either the path to an
+    executable file or a script file that can be run with a given tool.
+register_executable()
+    Register new subclasses of Executable that can be returned by get_executable().
 """
+
 from __future__ import with_statement
 import os.path
 import re
 import subprocess
 import sys
+import warnings
 
 version_pattern = re.compile(r'\b(?P<version>\d[\.\d]*([a-z]*\d)*)\b')
 version_pattern_matlab = re.compile(r'(?<=Version: )(?P<version>\d.+)\b')
@@ -42,7 +51,7 @@ class Executable(object):
             try:
                 self.path = self._find_executable(path or self.default_executable_name)
             except Warning, errmsg:
-                print errmsg
+                warnings.warn(errmsg)
                 self.path = path
         if self.name is None:
             self.name = name or os.path.basename(self.path)
