@@ -21,7 +21,11 @@ from operator import or_
 from formatting import get_formatter
 import dependency_finder
 from sumatra.core import TIMESTAMP_FORMAT
+from sumatra.users import get_user
 from versioncontrol import VersionControlError
+import logging
+
+logger = logging.getLogger("Sumatra")
 
 
 def assert_equal(a, b, msg=''):
@@ -34,15 +38,22 @@ class MissingInformationError(Exception):
 
 class Record(object):
     """
-
+    The :class:`Record` class has two main roles: capturing information about
+    the context of a computation, and storing this information for later
+    retrieval.
     """
 
     def __init__(self, executable, repository, main_file, version, launch_mode,
                  datastore, parameters={}, input_data=[], script_arguments='',
                  label=None, reason='', diff='', user='', on_changed='error',
-                 input_datastore=None, stdout_stderr='Not launched.'):
-        self.timestamp = datetime.now() # might need to allow for this to be set as argument to allow for distributed/batch simulations on machines with out-of-sync clocks
-        self.label = label or self.timestamp.strftime(TIMESTAMP_FORMAT)
+                 input_datastore=None, stdout_stderr='Not launched.',
+                 timestamp=None, timestamp_format=TIMESTAMP_FORMAT):
+        # we allow for the timestamp to be set as an argument to allow for
+        # distributed/batch simulations on machines with out-of-sync clocks,
+        # but only do this if you really know what you're doing, otherwise the
+        # association of output data with this record may be incorrect
+        self.timestamp = timestamp or datetime.now() 
+        self.label = label or self.timestamp.strftime(timestamp_format)
         assert len(self.label) > 0
         self.reason = reason
         self.duration = None
@@ -67,6 +78,7 @@ class Record(object):
     def register(self, working_copy):
         """Record information about the environment."""
         # Check the code hasn't changed and the version is correct
+        logger.debug("Checking code")
         if len(self.diff) == 0:
             assert not working_copy.has_changed()
         assert_equal(working_copy.current_version(), self.version, "version")
@@ -76,6 +88,7 @@ class Record(object):
                 normpath(join(cwd_relative_to_wc, basename(self.main_file)))):
             raise VersionControlError("Main file %s is not under version control" % self.main_file)
         # Record dependencies
+        logger.debug("Recording dependencies")
         self.dependencies = []
         if self.executable.requires_script:
             if self.main_file is None:
@@ -88,18 +101,24 @@ class Record(object):
                     self.dependencies.extend(dependency_finder.find_dependencies(main_file, self.executable))
             # if self.on_changed is 'error', should check that all the dependencies have empty diffs and raise an UncommittedChangesError otherwise
         # Record platform information
+        logger.debug("Recording platform information")
         self.platforms = self.launch_mode.get_platform_information()
+        # Record information about the current user
+        self.user = get_user(working_copy)
 
     def run(self, with_label=False):
         """
         Launch the simulation or analysis.
 
-        with_label - adds the record label either to the parameter file
-                     (with_label="parameters") or to the end of the command
-                     line (with_label="cmdline"), and appends the label to the
-                     datastore root. This allows the program being run to
-                     create files in a directory specific to this run.
+        *with_label*
+            adds the record label either to the parameter file
+            (`with_label="parameters"`) or to the end of the command line
+            (`with_label="cmdline"`), and appends the label to the datastore
+            root. This allows the program being run to create files in a
+            directory specific to this run.
+
         """
+        logger.debug("Launching computation")
         data_label = None
         if with_label:
             if with_label == 'parameters':
@@ -147,6 +166,14 @@ class Record(object):
         return "Record #%s" % self.label
 
     def describe(self, format='text', mode='long'):
+        """
+        Return a description of the record.
+        
+        *mode*:
+            either 'long' or 'short'
+        *format*
+            either 'text' or 'html'
+        """
         formatter = get_formatter(format)([self])
         return formatter.format(mode)
 
@@ -172,6 +199,14 @@ class Record(object):
         self.datastore.delete(*self.output_data)
         self.output_data = []
 
+    @property
+    def command_line(self):
+        """
+        Return the command-line string for the computation captured by this
+        record.
+        """
+        return self.launch_mode.generate_command(self.executable, self.main_file, self.script_arguments)
+
 
 class RecordDifference(object):
     """Represents the difference between two Record objects."""
@@ -196,12 +231,8 @@ class RecordDifference(object):
             if rec.parameters:
                 rec.parameters.pop("sumatra_label", 1)
         self.parameters_differ = recordA.parameters != recordB.parameters
-        self.input_data_differ = recordA.input_data != recordB.input_data  # now that input_data is a list of DataKeys, need to make this a property, like data_differ
         self.script_arguments_differ = recordA.script_arguments != recordB.script_arguments
         self.launch_mode_differs = recordA.launch_mode != recordB.launch_mode
-        #self.platforms
-        #self.datastore = datastore
-        #self.output_data = None
         self.diff_differs = recordA.diff != recordB.diff
 
     def __nonzero__(self):
@@ -215,7 +246,7 @@ class RecordDifference(object):
         """
         return reduce(or_, (self.executable_differs, self.code_differs,
                             self.input_data_differ, self.script_arguments_differ,
-                            self.parameters_differ, self.data_differs))
+                            self.parameters_differ, self.output_data_differ))
 
     def __repr__(self):
         s = "RecordDifference(%s, %s):" % (self.recordA.label, self.recordB.label)
@@ -225,7 +256,7 @@ class RecordDifference(object):
             s += 'C'
         if self.parameters_differ:
             s += 'P'
-        if self.data_differs:
+        if self.output_data_differ:
             s += 'D'
         if self.input_data_differ:
             s += 'I'
@@ -263,10 +294,12 @@ class RecordDifference(object):
                 diffs[name] = (None, depsB[name])
         return diffs
 
-    def _list_datakeys(self):
+    def _list_datakeys(self, direction):
         keys = {self.recordA.label: {}, self.recordB.label: {}}
+        assert direction in ('input_data', 'output_data')
         for rec in self.recordA, self.recordB:
-            for key in rec.output_data:
+            dataset = getattr(rec, direction)
+            for key in dataset:
                 ignore = False
                 name = basename(key.path) # not sure this makes sense for archive data store
                 if key.metadata['mimetype']:
@@ -279,39 +312,42 @@ class RecordDifference(object):
                         ignore = True
                         break
                 if not ignore:
-                    keys[rec.label][name] = key
+                    keys[rec.label][key.digest] = key
         return keys
 
-    @property
-    def data_differs(self):  # rename to "output_data_differs"
-        keys = self._list_datakeys()
-        filenamesA = set(keys[self.recordA.label].keys())
-        filenamesB = set(keys[self.recordB.label].keys())
-        if len(filenamesA) == len(filenamesB) == 0:
+    def _data_differ(self, direction):
+        keys = self._list_datakeys(direction)
+        A = set(keys[self.recordA.label].keys())
+        B = set(keys[self.recordB.label].keys())
+        if len(A) == len(B) == 0:
             return False
-        if filenamesA.difference(filenamesB):
+        if A.difference(B):
             return True
-        differs = {}
-        for filename in filenamesA:
-            differs[filename] = keys[self.recordA.label][filename].digest != keys[self.recordB.label][filename].digest # doesn't account for same-after-sorting
-        return reduce(or_, differs.values())
+        else:
+            return False
 
     @property
-    def data_differences(self): # rename to "output_data_differences"
-        keys = self._list_datakeys()
-        A = keys[self.recordA.label]
-        B = keys[self.recordB.label]
-        diffs = {}
-        for name in A:
-            if name in B:
-                if A[name].digest != B[name].digest:
-                    diffs[name] = (A[name], B[name])
-            else:
-                diffs[name] = (A[name], None)
-        for name in B:
-            if name not in B:
-                diffs[name] = (None, B[name])
-        return diffs
+    def output_data_differ(self):
+        return self._data_differ('output_data')
+
+    @property
+    def input_data_differ(self):
+        return self._data_differ('input_data')
+
+    def _data_differences(self, direction):
+        keys = self._list_datakeys(direction)
+        A = set(keys[self.recordA.label])
+        B = set(keys[self.recordB.label])
+        return ([keys[self.recordA.label][digest] for digest in A.difference(B)],
+                [keys[self.recordB.label][digest] for digest in B.difference(A)])
+
+    @property
+    def output_data_differences(self):
+        return self._data_differences('output_data')
+
+    @property
+    def input_data_differences(self):
+        return self._data_differences('input_data')
 
     @property
     def launch_mode_differences(self):
