@@ -19,22 +19,38 @@ try:
     have_django = True
 except ImportError:
     have_django = False
-from http_store import HttpRecordStore
+try:
+    import httplib2
+    have_http = True
+except ImportError:
+    have_http = False
+    
+if have_http:
+    from http_store import HttpRecordStore
+    
 DefaultRecordStore = have_django and DjangoRecordStore or ShelveRecordStore
 
-def get_record_store(path):
-    if path[:4] == "http":
-        store = HttpRecordStore(path)
-    elif os.path.exists(path):
+
+def get_record_store(uri):
+    """
+    Return the :class:`RecordStore` object found at the given URI (which may be
+    a URL or filesystem path).
+    """
+    if uri[:4] == "http":
+        if have_http:
+            store = HttpRecordStore(uri)
+        else:
+            raise Exception("Cannot access record store: httplib2 is not installed.")
+    elif os.path.exists(uri):
         try:
-            store = ShelveRecordStore(path)
+            store = ShelveRecordStore(uri)
         except Exception, err:
             if have_django:
-                store = DjangoRecordStore(path)
+                store = DjangoRecordStore(uri)
             else:
                 raise err
-    elif os.path.splitext(path)[1] == ".shelf":
-        store = ShelveRecordStore(path)
+    elif os.path.splitext(uri)[1] == ".shelf":
+        store = ShelveRecordStore(uri)
     else:
-        store = DefaultRecordStore(path)
+        store = DefaultRecordStore(uri)
     return store
