@@ -8,7 +8,7 @@ from sumatra import programs, launch, datastore, records, versioncontrol, parame
 import os.path
 import tagging.fields
 from tagging.models import Tag
-
+from datetime import datetime
 
 class SumatraObjectsManager(models.Manager):
     
@@ -54,11 +54,17 @@ class Project(BaseModel):
     name = models.CharField(max_length=200)
     description = models.TextField(blank=True)
 
+    class Meta:
+        ordering = ('id',)
+
     def get_name(self):
         return self.name or self.id
 
     def __unicode__(self):
         return self.id
+    
+    def last_updated(self):
+        return self.record_set.all().aggregate(models.Max('timestamp'))["timestamp__max"] or datetime(1970, 1, 1, 0, 0, 0)
 
 
 class Executable(BaseModel):
@@ -82,16 +88,15 @@ class Dependency(BaseModel):
     path = models.CharField(max_length=200)
     version = models.CharField(max_length=20)
     diff = models.TextField(blank=True)
+    source = models.CharField(max_length=200, null=True, blank=True)
     module = models.CharField(max_length=50) # should be called language, or something
     
     def __unicode__(self):
         return "%s (%s) version=%s" % (self.name, self.path, self.version)
     
     def to_sumatra(self):
-        dep = getattr(dependency_finder, self.module).Dependency(self.name, self.path, self.version)
-        if self.diff:
-            dep.diff = self.diff
-        return dep
+        return getattr(dependency_finder, self.module).Dependency(
+                    self.name, self.path, self.version, self.diff, self.source)
         
     class Meta:
         ordering = ['name']
@@ -101,6 +106,7 @@ class Repository(BaseModel):
     # the following should be unique together.
     type = models.CharField(max_length=20)
     url = models.URLField(verify_exists=False)
+    upstream = models.URLField(verify_exists=False, null=True, blank=True)
 
     def __unicode__(self):
         return self.url
@@ -108,7 +114,9 @@ class Repository(BaseModel):
     def to_sumatra(self):
         for m in versioncontrol.vcs_list:
             if hasattr(m, self.type):
-                return getattr(m, self.type)(self.url)
+                repos = getattr(m, self.type)(self.url)
+                repos.upstream = self.upstream
+                return repos
         raise Exception("Repository type %s not supported." % self.type)
 
 
@@ -165,6 +173,9 @@ class DataKey(BaseModel):
     digest = models.CharField(max_length=40)
     metadata = models.TextField(blank=True)
     
+    class Meta:
+        ordering = ('path',)
+
     def get_metadata(self):
         return eval(self.metadata) # should probably use json.decode
     
@@ -220,6 +231,9 @@ class Record(BaseModel):
     # parameters which will be used in the fulltext search (see sumatra.web.services fulltext_search)
     params_search = ('label','reason', 'duration', 'main_file', 'outcome', 'user', 'tags') 
 
+    class Meta:
+        ordering = ('-timestamp',)
+
     def to_sumatra(self):
         record = records.Record(
             self.executable.to_sumatra(),
@@ -235,12 +249,11 @@ class Record(BaseModel):
             self.reason,
             self.diff,
             self.user,
-            input_datastore=self.input_datastore.to_sumatra())
-
+            input_datastore=self.input_datastore.to_sumatra(),
+            timestamp=self.timestamp)
         record.stdout_stderr = self.stdout_stderr
         record.duration = self.duration
         record.outcome = self.outcome
-        record.timestamp = self.timestamp
         record.tags = set(tag.name for tag in Tag.objects.get_for_object(self))
         record.output_data = [key.to_sumatra() for key in self.output_data.all()]
         record.dependencies = [dep.to_sumatra() for dep in self.dependencies.all()]
@@ -251,4 +264,7 @@ class Record(BaseModel):
         return self.label
     
     def tag_objects(self):
-        return Tag.objects.get_for_object(self)
+        return Tag.objects.get_for_object(self) 
+
+    def command_line(self):
+        return self.to_sumatra().command_line
