@@ -39,13 +39,21 @@ def run(cmd):
 
 def create_mercurial_repos(repos_dir):
     orig_wd = os.getcwd()
-    os.chdir(repos_dir)
-    run("hg init")
-    os.chdir(orig_wd)
     run("hg init")
     run("hg add")
     run("hg commit -m 'Creating example project'")
-    run("hg push %s" % repos_dir)
+    os.chdir(repos_dir)
+    run("hg clone %s" % orig_wd)
+    os.chdir(orig_wd)
+
+def create_git_repos(repos_dir):
+    orig_wd = os.getcwd()
+    run("git init")
+    run("git add .")
+    run("git commit -m 'Creating example project'")
+    os.chdir(repos_dir)
+    run("git clone %s" % orig_wd)
+    os.chdir(orig_wd)
 
 def create_subversion_repos(repos_dir):
     run("svnadmin create %s" % repos_dir)
@@ -122,7 +130,7 @@ def run_test(repos, options, working_dir, repos_dir):
     copy_example_project(working_dir)
     os.chdir(working_dir)
 
-    exec("create_%s_repos('%s')" % (repos, repos_dir))
+    exec("create%s_repos('%s')" % (repos, repos_dir))
 
     getting_started(options)
 
@@ -130,16 +138,17 @@ def run_test(repos, options, working_dir, repos_dir):
     os.chdir(cwd)
 run_test.__test__ = False # nose should not treat this as a test
     
-def main():    
-    for repos in 'subversion', 'mercurial':  
+def test_all():
+    #for repos in [m.__name__.split('.')[-1] for m in vcs_list]:
+    for repos in ('_git', '_subversion', '_mercurial'):  
         for options in ({}, {'store': ".smt/records.shelf"}):
             working_dir, repos_dir = create_temporary_directories()
             print working_dir, repos_dir
-            run_test(repos, options, working_dir, repos_dir)
+            yield run_test, repos, options, working_dir, repos_dir
             shutil.rmtree(working_dir)
             shutil.rmtree(repos_dir)
             
 if __name__ == "__main__":
-    #run_test('mercurial', {}, "/Users/andrew/tmp/SumatraTestDj", "/Users/andrew/tmp/smt_example_repos")
-    #run_test('mercurial', {'store': ".smt/records.shelf"}, "/Users/andrew/tmp/SumatraTest", "/Users/andrew/tmp/smt_example_repos")
-    main()
+    for args in test_all():
+        test = args[0]
+        test(*args[1:])
